SunPy image
***********

The image submodule contains routines to process images (i.e. `numpy` arrays).
The routines in this submodule are generally exposed through map-specific
functions in other places.

.. automodapi:: sunpy.image

.. automodapi:: sunpy.image.resample

.. automodapi:: sunpy.image.transform

.. automodapi:: sunpy.image.coalignment
